@@ -97,6 +97,7 @@ static gboolean load_fish_image          (FishApplet *fish);
 static void     update_pixmap            (FishApplet *fish);
 static void     something_fishy_going_on (FishApplet *fish,
 					  const char *message);
+static void     set_tooltip              (FishApplet *fish);
 
 static GType fish_applet_get_type (void);
 
@@ -309,6 +310,7 @@ display_preferences_dialog (BonoboUIComponent *uic,
 {
 	GladeXML  *xml;
 	GtkWidget *button;
+	GConfClient *client;
 
 	if (fish->preferences_dialog) {
 		gtk_window_set_screen (GTK_WINDOW (fish->preferences_dialog),
@@ -370,6 +372,19 @@ display_preferences_dialog (BonoboUIComponent *uic,
 			   NULL /* label_post */,
 			   "command" /* key */);
 
+	client = gconf_client_get_default ();
+	if (gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL)) {
+		GtkWidget *w;
+
+		w = glade_xml_get_widget (xml, "command_entry");
+		g_assert (w != NULL);
+		gtk_widget_set_sensitive (w, FALSE);
+
+		w = glade_xml_get_widget (xml, "command_label");
+		g_assert (w != NULL);
+		gtk_widget_set_sensitive (w, FALSE);
+	}
+
 	fish->frames_spin = glade_xml_get_widget (xml, "frames_spin");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (fish->frames_spin),
 				   fish->n_frames);
@@ -490,7 +505,7 @@ display_about_dialog (BonoboUIComponent *uic,
 	g_free (authors [0]);
 
 	if (pixbuf)
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (pixbuf);
 
 	gtk_window_set_wmclass (
 		GTK_WINDOW (fish->about_dialog), "fish", "Fish");
@@ -509,8 +524,8 @@ static void
 set_ally_name_desc (GtkWidget  *widget,
 		    FishApplet *fish)
 {
-	const char *name_format = _("%s the GNOME Fish");
-	const char *desc_format = _("%s the GNOME Fish, a contemporary oracle");
+	const char *name_format = _("%s the Fish");
+	const char *desc_format = _("%s the Fish, a contemporary oracle");
 	AtkObject  *obj;
 	char       *desc, *name;
 
@@ -602,7 +617,7 @@ update_fortune_dialog (FishApplet *fish)
 	g_free (text);
 
 	/* xgettext:no-c-format */
-	label_text = g_strdup_printf (_("%s the GNOME Fish Says:"), fish->name);
+	label_text = g_strdup_printf (_("%s the Fish Says:"), fish->name);
 
 	text = g_strdup_printf ("<big><big>%s</big></big>", label_text);
 	gtk_label_set_markup (GTK_LABEL (fish->fortune_label), text);
@@ -779,6 +794,7 @@ name_changed_notify (GConfClient *client,
 	fish->name = g_strdup (value);
 
 	update_fortune_dialog (fish);
+	set_tooltip (fish);
 	set_ally_name_desc (GTK_WIDGET (fish), fish);
 
 	if (fish->name_entry &&
@@ -925,7 +941,7 @@ init_fools_day (void)
 	fools_hour_end   = 12; /* Apparently jokes should stop at midday */
 	
 	for (i = 0; spanish_timezones [i]; i++)
-		if (!g_strcasecmp (spanish_timezones [i], location)) {
+		if (!g_ascii_strcasecmp (spanish_timezones [i], location)) {
 			/* Hah!, We are in Spain or Mexico
 			 * Spanish fool's day is 28th December
 			 */
@@ -1290,12 +1306,12 @@ fish_applet_expose_event (GtkWidget      *widget,
 	else
 		src_x += ((width * fish->current_frame) / fish->n_frames);
 
-	gdk_draw_pixmap (widget->window,
-			 widget->style->fg_gc [GTK_WIDGET_STATE (widget)],
-			 fish->pixmap,
-			 src_x, src_y,
-			 event->area.x, event->area.y,
-			 event->area.width, event->area.height);
+	gdk_draw_drawable (widget->window,
+			   widget->style->fg_gc [GTK_WIDGET_STATE (widget)],
+			   fish->pixmap,
+			   src_x, src_y,
+			   event->area.x, event->area.y,
+			   event->area.width, event->area.height);
 
         return FALSE;
 }
@@ -1412,6 +1428,8 @@ static void
 set_tooltip (FishApplet *fish)
 {
 	GtkTooltips *tooltips;
+	const char  *desc_format = _("%s the Fish, the fortune teller");
+	char        *desc;
 
 	tooltips = gtk_tooltips_new ();
 	g_object_ref (tooltips);
@@ -1419,8 +1437,9 @@ set_tooltip (FishApplet *fish)
 
 	g_object_set_data (G_OBJECT (fish), "tooltips", tooltips);
 
-	gtk_tooltips_set_tip (tooltips, GTK_WIDGET (fish),
-			      _("GNOME Fish, the fortune teller"), NULL);
+	desc = g_strdup_printf (desc_format, fish->name);
+	gtk_tooltips_set_tip (tooltips, GTK_WIDGET (fish), desc, NULL);
+	g_free (desc);
 }
 
 static void
@@ -1548,19 +1567,29 @@ fish_applet_fill (FishApplet *fish)
 	}
 
 	fish->rotate = panel_applet_gconf_get_bool (applet, "rotate", &error);
-	fish->rotate = FALSE;
 	if (error) {
 		g_warning ("Error getting 'rotate' preference: %s", error->message);
 		g_error_free (error);
 		error = NULL;
 
-		fish->rotate = TRUE; /* Fallback */
+		fish->rotate = FALSE; /* Fallback */
 	}
 
 	panel_applet_setup_menu_from_file (
 		applet, NULL, "GNOME_FishApplet.xml",
 		NULL, fish_menu_verbs, fish);
 
+	if (panel_applet_get_locked_down (applet)) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (applet);
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/FishPreferences",
+					      "hidden", "1",
+					      NULL);
+	}
+
 	setup_fish_widget (fish);
 
 	return TRUE;
