@@ -436,6 +436,17 @@ workspace_switcher_applet_fill (PanelApplet *applet)
 					   pager_menu_verbs,
 					   pager);
 
+	if (panel_applet_get_locked_down (PANEL_APPLET (pager->applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (pager->applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/PagerPreferences",
+					      "hidden", "1",
+					      NULL);
+	}
+
 	return TRUE;
 }
 
@@ -619,6 +630,18 @@ num_workspaces_value_changed (GtkSpinButton *button,
                                             gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (pager->num_workspaces_spin)));
 }
 
+static gboolean
+workspaces_tree_focused_out (GtkTreeView   *treeview,
+			     GdkEventFocus *event,
+			     PagerData     *pager)
+{
+	GtkTreeSelection *selection;
+
+	selection = gtk_tree_view_get_selection (treeview);
+	gtk_tree_selection_unselect_all (selection);
+	return TRUE;
+}
+
 static void 
 workspace_name_edited (GtkCellRendererText *cell_renderer_text,
 		       const gchar         *path,
@@ -817,6 +840,9 @@ setup_dialog (GladeXML  *xml,
 				     pager,
 				     pager->applet);
 
+	g_signal_connect (G_OBJECT (pager->workspaces_tree), "focus_out_event",
+			  (GCallback) workspaces_tree_focused_out, pager);
+
 	pager->workspaces_store = gtk_list_store_new (1, G_TYPE_STRING, NULL);
 	update_workspaces_model (pager);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (pager->workspaces_tree), GTK_TREE_MODEL (pager->workspaces_store));
