@@ -492,6 +492,11 @@ panel_properties_dialog_opacity_changed (PanelPropertiesDialog *dialog)
 
 	percentage = gtk_range_get_value (GTK_RANGE (dialog->opacity_scale));
 
+	if (percentage >= 98)
+		percentage = 100;
+	else if (percentage <= 2)
+		percentage = 0;
+
 	opacity = (percentage / 100) * 65535;
 
 	panel_profile_set_background_opacity (dialog->toplevel, opacity);
@@ -645,6 +650,7 @@ panel_properties_dialog_response (PanelPropertiesDialog *dialog,
 static void
 panel_properties_dialog_destroy (PanelPropertiesDialog *dialog)
 {
+	panel_toplevel_unblock_auto_hide (PANEL_TOPLEVEL (dialog->toplevel));
 	g_object_set_qdata (G_OBJECT (dialog->toplevel),
 			    panel_properties_dialog_quark,
 			    NULL);
@@ -976,6 +982,8 @@ panel_properties_dialog_new (PanelToplevel *toplevel,
 	panel_properties_dialog_update_for_attached (dialog,
 						     panel_toplevel_get_is_attached (dialog->toplevel));
 
+	panel_toplevel_block_auto_hide (dialog->toplevel);
+
 	gtk_widget_show (dialog->properties_dialog);
 
 	return dialog;
