@@ -21,6 +21,7 @@
 #include "panel-typebuiltins.h"
 #include "panel-applet-frame.h"
 #include "panel-globals.h"
+#include "panel-profile.h"
 
 #define MOVE_INCREMENT 2
 
@@ -32,6 +33,7 @@ typedef enum {
 
 enum {
 	SIZE_CHANGE_SIGNAL,
+	BACK_CHANGE_SIGNAL,
 	APPLET_MOVE_SIGNAL,
 	APPLET_ADDED_SIGNAL,
 	APPLET_REMOVED_SIGNAL,
@@ -71,6 +73,9 @@ static void panel_widget_state_changed  (GtkWidget        *widget,
 static void panel_widget_style_set      (GtkWidget        *widget,
 					 GtkStyle         *previous_style);
 
+static void panel_widget_background_changed (PanelBackground *background,
+					     PanelWidget     *panel);
+
 static void panel_widget_push_move_applet   (PanelWidget      *panel,
                                              GtkDirectionType  dir);
 static void panel_widget_switch_move_applet (PanelWidget      *panel,
@@ -336,6 +341,17 @@ panel_widget_class_init (PanelWidgetClass *class)
                               G_TYPE_NONE,
                               0);
 
+	panel_widget_signals[BACK_CHANGE_SIGNAL] =
+                g_signal_new ("back_change",
+                              G_TYPE_FROM_CLASS (object_class),
+                              G_SIGNAL_RUN_LAST,
+                              G_STRUCT_OFFSET (PanelWidgetClass, back_change),
+                              NULL,
+                              NULL, 
+                              panel_marshal_VOID__VOID,
+                              G_TYPE_NONE,
+                              0);
+
 	panel_widget_signals[APPLET_MOVE_SIGNAL] =
                 g_signal_new ("applet_move",
                               G_TYPE_FROM_CLASS (object_class),
@@ -432,6 +448,7 @@ panel_widget_class_init (PanelWidgetClass *class)
                               0);
 
 	class->size_change = NULL;
+	class->back_change = NULL;
 	class->applet_move = NULL;
 	class->applet_added = NULL;
 	class->applet_removed = NULL;
@@ -1709,7 +1726,9 @@ panel_widget_instance_init (PanelWidget *panel)
 	panel->drop_widget   = widget;
 	panel->open_dialogs  = NULL;
 
-	panel_background_init (&panel->background);
+	panel_background_init (&panel->background,
+			       (PanelBackgroundChangedNotify) panel_widget_background_changed,
+			       panel);
 
 	panels = g_slist_append (panels, panel);
 }
@@ -1829,6 +1848,8 @@ panel_widget_applet_drag_start (PanelWidget *panel,
 	g_message("Starting drag [grabbed] on a %s at %p\n",
 		  g_type_name(G_TYPE_FROM_INSTANCE(applet)), applet);
 #endif
+	panel_toplevel_block_auto_hide (panel->toplevel);
+
 	if (!panel_widget_applet_drag_start_no_grab (panel, applet, drag_off))
 		return;
 
@@ -1864,6 +1885,7 @@ panel_widget_applet_drag_end (PanelWidget *panel)
 	gdk_pointer_ungrab (GDK_CURRENT_TIME);
 	gtk_grab_remove (panel->currently_dragged_applet->applet);
 	panel_widget_applet_drag_end_no_grab (panel);
+	panel_toplevel_unblock_auto_hide (panel->toplevel);
 	gdk_flush ();
 }
 
@@ -2082,7 +2104,8 @@ panel_widget_applet_move_to_cursor (PanelWidget *panel)
 			    panel_widget_is_cursor (new_panel,10) &&
 			    panel_screen_from_panel_widget (panel) ==
 			    panel_screen_from_panel_widget (new_panel) &&
-			    !g_slist_find (forb, new_panel)) {
+			    !g_slist_find (forb, new_panel) &&
+			    ! panel_toplevel_get_locked_down (new_panel->toplevel)) {
 				pos = panel_widget_get_moveby (new_panel, 0, ad->drag_off);
 
 				if (pos < 0) pos = 0;
@@ -2216,7 +2239,7 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event)
 				return TRUE;
 			}
 
-			if ( ! commie_mode &&
+			if ( ! panel_profile_get_locked_down () &&
 			    bevent->button == 2) {
 				guint32 time_ = bevent->time;
 				/* time on sent events seems to be bogus */
@@ -2607,6 +2630,16 @@ panel_widget_set_size (PanelWidget *panel_widget,
 	gtk_widget_queue_resize (GTK_WIDGET (panel_widget));
 }
 
+static void
+panel_widget_background_changed (PanelBackground *background,
+				 PanelWidget     *panel)
+{
+	g_return_if_fail (PANEL_IS_WIDGET (panel));
+	g_signal_emit (G_OBJECT (panel),
+		       panel_widget_signals [BACK_CHANGE_SIGNAL],
+		       0);
+}
+
 static void 
 panel_widget_push_move_applet (PanelWidget     *panel,
                                GtkDirectionType dir)
@@ -2728,7 +2761,9 @@ panel_widget_tab_move (PanelWidget *panel,
 	if (!new_panel && previous_panel)
 		new_panel = previous_panel;
 	
-	if (new_panel && (new_panel != panel))
+	if (new_panel &&
+	    (new_panel != panel) &&
+	    ! panel_toplevel_get_locked_down (new_panel->toplevel))
 		panel_widget_reparent (panel, new_panel, ad->applet, 0);
 }
 
